@@ -1,10 +1,14 @@
+"""Rule dataclass module"""
+
 from typing import Pattern
 from dataclasses import dataclass
 
-from ccheck.domain.token_type import TokenType
+from ccheck.domain.token.token_type import TokenType
 
 
-@dataclass
+@dataclass(slots=True)
 class Rule:
+    """Rule dataclass"""
+
     regex: Pattern[str]
     type: TokenType
